## OMDOX

OMDOX is a lightweight documentation builder that utilises [jinja2][0] templates as placeholders for markdown and code snippets.


More information can be found at http://omdox.obscuremetaphor.co.uk/
